from collections import defaultdict

# you can use this as a template
SECRET_KEY = 'not-really-a-secret'

SQLALCHEMY_DATABASE_URI = 'sqlite:////tmp/oraculum_db.sqlite'
SHOW_DB_URI = False

OIDC_CLIENT_SECRETS = '/etc/oraculum/client_secrets.json'
OIDC_ID_TOKEN_COOKIE_SECURE = False
OIDC_REQUIRE_VERIFIED_EMAIL = False
OIDC_SCOPES = ['openid', 'email', 'profile']

# Celery config
CELERY_BROKER_URL = 'redis://localhost:6379'
CELERY_RESULT_BACKEND = 'redis://localhost:6379'

# MAX_DB_AGE will be ignored as per IGNORE_CACHE_TIMESTAMP setting bellow, data from caches might be used no matter their age
# make sure to set up cron with "runcli.py sync" if set to True
# The idea is to have sync run every hour and leave MAX_DB_AGE big enough not to drop local_cache
# before sync finishes
MAX_DB_AGE = 14400 # Max cache age allowed in seconds (240 minutes)

# IGNORE_CACHE_TIMESTAMP sets how oraculum verifies data aga in cache
# values can be 'local', 'db' or None
# "local" - always trust both local and database caches, plan refresh if database data are missing
# "db" - verify only local cache age, always trust database cache, plan refresh if database data are missing
# None - verify age of both, local and database caches, plan refresh if data are too old
IGNORE_CACHE_TIMESTAMP = 'db'

ENABLE_LOCAL_CACHE = True

ACTIVITY_REQUIRED = 14 # Cache data for users who used the service in at least last 14 days

PACKAGE_MAINTAINERS_JSON_URL = "https://src.fedoraproject.org/extras/pagure_owner_alias.json"
ORPHANS_JSON_URL = "https://churchyard.fedorapeople.org/orphans.json"
KOSCHEI_API_URL = "https://koschei.fedoraproject.org/api/v1/packages"
HEALTH_CHECK_URL = "https://repochecker.decathorpe.com/data/"
KOJI_URL = "https://koji.fedoraproject.org/koji/"
KOJIHUB_URL = "https://koji.fedoraproject.org/kojihub/"
BLOCKERBUGS_URL = "https://qa.fedoraproject.org/blockerbugs/"
SCHEDULE_URL = "https://fedorapeople.org/groups/schedule/f-%d/f-%d-key.ics"

EPEL_RELEASES = [6, 7, 8]

# How often should be watchdog triggered
# (For sending emails with health check report and counter resetting if ACTIVE_WATCHDOG)
WATCHDOG_INTERVAL = 86400

# ACTIVE_WATCHDOG handles counter reset to make oraculum even more robust in production deployment
# Allows scheduling tasks again in cases when redis failed/crashed during runtime
ACTIVE_WATCHDOG = True

# Specify groups that are allowed to own packages, regexes and explicit names are allowed
# Only groups ending with "-sig" can own packages as per https://pagure.io/fedora-infrastructure/issue/5478#comment-9109
ALLOWED_PACKAGER_GROUPS = ["^sssd-maintainers$", ".+[-_]sig$"]

SYNC_INTERVALS = defaultdict(lambda: 3600) # Default sync interval
# You can set specific tasks' sync intervals here, unset tasks will be refreshed in the
#  default interval above
# Available syncers:
#    blocker_trackers
#    bodhi_overrides
#    bodhi_updates
#    easyfix
#    fedora_easy_karma
#    fedora_manual_testing
#    fedora_releases
#    ftbfs_trackers
#    fti_trackers
#    health_check_data
#    heart_beat
#    koschei_data
#    landing_page
#    orphans_json
#    packager_dashboard_static_user_data
#    packager_dashboard_package_bugs
#    packager_dashboard_package_prs
#    packager_dashboard_package_versions
#    packages_owners_json
#    pagure_groups
SYNC_INTERVALS["heart_beat"] = 10
SYNC_INTERVALS["pagure_groups"] = 7200
SYNC_INTERVALS["packager_dashboard_static_user_data"] = 3600
SYNC_INTERVALS["packager_dashboard_package_bugs"] = 7200
SYNC_INTERVALS["packager_dashboard_package_prs"] = 7200
SYNC_INTERVALS["packager_dashboard_package_versions"] = 43200

# Specify time (seconds) after which are tasks considered to be in "rotting state"
TASKS_ROT_AFTER = 7200

# FAILURE EMAILS
# To receive failres via email, you need to set up smtp connection details and set SEND_ERROR_EMAILS to True
SEND_ERROR_EMAILS = False
SMTP_SERVER = ""
SMTP_PORT = 465
SMTP_LOGIN = ""
SMTP_SENDER = ""
SMTP_PASSWORD = ""

# List of email addresses to send failures to
ADMIN_EMAILS = []
