# Copyright 2014, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#    Lukas Brabec <lbrabec@redhat.com>

import re
import requests

from flask_login import login_required
from flask import request, Response, stream_with_context

from oraculum import app

method_requests_mapping = {
    'GET': requests.get,
    'HEAD': requests.head,
    'POST': requests.post,
    'PUT': requests.put,
    'DELETE': requests.delete,
    'PATCH': requests.patch,
    'OPTIONS': requests.options,
}


@app.route('/api/v1/proxy/<path:url>', methods=['GET', 'OPTIONS'])
def api_v1_proxy_get(url):
    return api_v1_proxy(url)


@app.route('/api/v1/proxy/<path:url>', methods=['HEAD', 'POST', 'PUT', 'DELETE', 'PATCH'])
@login_required
def api_v1_proxy_other(url):
    return api_v1_proxy(url)


def api_v1_proxy(url):
    # fix when apache is eating the doubleslash
    url = re.sub(r"^http(s)?:/+", r"http\1://", url)

    app.logger.debug("proxying %s %s" % (request.method, url))

    # cherry pick headers to forward
    headers = {}
    for header in ['Authorization']:
        if request.headers.get(header):
            headers[header] = request.headers.get(header)

    requests_function = method_requests_mapping[request.method]
    fwd_request = requests_function(url, stream=True, params=request.args,
                                    json=request.json,
                                    headers=headers)
    response = Response(stream_with_context(fwd_request.iter_content()),
                        content_type=fwd_request.headers['content-type'],
                        status=fwd_request.status_code)

    #response.headers.add('Access-Control-Allow-Origin', '*')
    response.headers.add('Access-Control-Allow-Headers', 'Content-Type,Authorization')
    response.headers.add('Access-Control-Allow-Methods', 'GET,PUT,POST,DELETE,OPTIONS')

    return response
