# Copyright 2014, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#    Josef Skladanka <jskladan@edhat.com>
#    Frantisek Zatloukal <fzatlouk@redhat.com>

import datetime

from flask import jsonify

from oraculum import app, CACHE
from oraculum.utils import bodhi

def get_current_releases():
    releases = CACHE.get('fedora_releases')["values"][:-1] # Cut the last element because we don't want to query rawhide
    return ["F" + str(i) for i in releases] + ["EPEL-" + str(i) for i in app.config['EPEL_RELEASES']]

def all_bodhi_updates():
    current_releases = get_current_releases()
    updates = {}
    for single_release in current_releases:
        app.logger.debug("Appending updates for release: %s" % single_release)
        updates[single_release] = bodhi.get_updates_from_bodhi(single_release)
    return updates


@app.route('/api/v1/libkarma/<release>', methods=['GET'])
def route_api_v1_libkarma(release):
    current_releases = get_current_releases()
    db_time = CACHE.get_refreshed_time('bodhi_updates')
    SYNC_INTERVALS = app.config['SYNC_INTERVALS']
    if datetime.datetime.utcnow() > db_time + datetime.timedelta(seconds=(SYNC_INTERVALS["bodhi_updates"]*4)):
        return jsonify({'error': 'Cached data are too old.'}), 503
    if release in current_releases:
        return jsonify(CACHE.get('bodhi_updates')[release])
    if release.lower() == 'all':
        return jsonify(CACHE.get('bodhi_updates'))
    return jsonify({'error': 'Release %s not found' % release}), 404
