#
# landing_page.py - Database model for landing page
#
# Copyright 2020, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Frantisek Zatloukal <fzatlouk@redhat.com>

import json

from oraculum import db
from datetime import datetime


class CachedData(db.Model):
    id = db.Column(db.Integer, primary_key=True)
    provider = db.Column(db.Text, unique=True)
    time_created = db.Column(db.DateTime, unique=False)
    raw_text = db.Column(db.Text, unique=False)

    def __init__(self, provider, raw_text):
        self.provider = provider
        self.time_created = datetime.utcnow()
        self.raw_text = raw_text
        self._parsed_raw_text = None

    @property
    def data(self):
        try:
            if self._parsed_raw_text is None:
                self._parsed_raw_text = json.loads(self.raw_text)
        except AttributeError:
            self._parsed_raw_text = json.loads(self.raw_text)
        return self._parsed_raw_text
