#
# blockerbugs.py - Blockerbugs parsers and utilities for QA Ladning Page
#
# Copyright 2020, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Frantisek Zatloukal <fzatlouk@redhat.com>
#   Josef Skladanka <jskladan@redhat.com>

import urllib

from oraculum import app, CACHE
from oraculum.utils.dashboard_helpers import get_json

BLOCKERBUGS_URL = urllib.parse.urljoin(app.config["BLOCKERBUGS_URL"], "api/v0/milestones/%d/%s/bugs")

def get_blockerbugs():
    data = {
        "beta_blockers": "NaN",
        "beta_blockers_proposed": "NaN",
        "beta_fe": "NaN",
        "beta_fe_proposed": "NaN",
        "final_blockers": "NaN",
        "final_blockers_proposed": "NaN",
        "final_fe": "NaN",
        "final_fe_proposed": "NaN"
    }
    releases = CACHE.get("fedora_releases")
    release = releases["branched"] or releases["rawhide"]

    resp_beta = get_json(BLOCKERBUGS_URL % (release, "beta"))
    resp_final = get_json(BLOCKERBUGS_URL % (release, "final"))

    beta_blockers, beta_fe, final_blockers, final_fe = (0, 0, 0, 0)
    beta_blockers_prop, beta_fe_prop, final_blockers_prop, final_fe_prop = (0, 0, 0, 0)

    for bug in resp_beta:
        if not (bug["active"]):
            continue
        if "accepted_blocker" in bug["type"]:
            beta_blockers += 1
        if "proposed_blocker" in bug["type"]:
            beta_blockers_prop += 1
        if "accepted_fe" in bug["type"]:
            beta_fe += 1
        if "proposed_fe" in bug["type"]:
            beta_fe_prop += 1

    for bug in resp_final:
        if not (bug["active"]):
            continue
        if "accepted_blocker" in bug["type"]:
            final_blockers += 1
        if "proposed_blocker" in bug["type"]:
            final_blockers_prop += 1
        if "accepted_fe" in bug["type"]:
            final_fe += 1
        if "proposed_fe" in bug["type"]:
            final_fe_prop += 1

    data = {
        "beta_blockers": beta_blockers,
        "beta_blockers_proposed": beta_blockers_prop,
        "beta_fe": beta_fe,
        "beta_fe_proposed": beta_fe_prop,
        "final_blockers": final_blockers,
        "final_blockers_proposed": final_blockers_prop,
        "final_fe": final_fe,
        "final_fe_proposed": final_fe_prop
    }

    return data
